﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.Diagnostics;
using System.Runtime.InteropServices;

namespace NewFriendsCounter
{
    public partial class MainForm : Form
    {   

        public int TodayFriendsCount
        {
            get 
            {
                if (!File.Exists("todayFriendsCount.dat"))
                {
                    File.WriteAllBytes("todayFriendsCount.dat", BitConverter.GetBytes(0));
                }                
                return BitConverter.ToInt32(File.ReadAllBytes("todayFriendsCount.dat"), 0);
            }
            set { File.WriteAllBytes("todayFriendsCount.dat", BitConverter.GetBytes(value)); }
        }

        public bool IsHandled
        {
            get
            {
                if (!File.Exists("HandledSign.dat"))
                {
                    File.WriteAllBytes("HandledSign.dat", BitConverter.GetBytes(false));
                }                
                return BitConverter.ToBoolean(File.ReadAllBytes("HandledSign.dat"), 0);
            }
            set
            {
                File.WriteAllBytes("HandledSign.dat", BitConverter.GetBytes(value));
                this.toolStripLabel_isHandled.Text = this.IsHandled ? "今日已处理" : "今日未处理";
                this.toolStripLabel_isHandled.ForeColor = this.IsHandled ? Color.Red : Color.Blue;              
            }
        }

        public MainForm()
        {
            InitializeComponent();
            this.timer1.Start();
        }      

        private void button1_Click(object sender, EventArgs e)
        {
            //已经处理过
            if (this.IsHandled)
            {
                DialogResult dialogResult = MessageBox.Show("今日已经执行过，是否还要继续操作？", "提醒", MessageBoxButtons.YesNo);               
                if (dialogResult == DialogResult.No)
                {
                    this.textBox_todayCount.Focus();
                    this.textBox_todayCount.SelectAll();
                    return;
                }
            }
            //计算、显示、复制、记录
            if (String.IsNullOrEmpty(this.textBox_todayCount.Text.Trim()))
            {
                MessageBox.Show("输入不能为空！");
                this.textBox_todayCount.Focus();
                return;
            }

            FileHelper fileHelper = new FileHelper();
            FileStatus fileStatus = fileHelper.VerifyFileIsOpen("每日新加好友记录.doc");
            if (fileStatus == FileStatus.Opened)
            {
                MessageBox.Show("请先关闭文件！");               
                this.textBox_todayCount.Focus();
                this.textBox_todayCount.SelectAll();
                return;
            }

            int todayFriendsCountNew = int.Parse(this.textBox_todayCount.Text.Trim());
            int incremeFriendsCount = todayFriendsCountNew - this.TodayFriendsCount;
            this.richTextBox_ShowNewCount.Text = string.Format("今日新加好友：{0} - {1} = {2}",
                                                                todayFriendsCountNew,
                                                                this.TodayFriendsCount,
                                                                incremeFriendsCount);
            Clipboard.SetText(this.richTextBox_ShowNewCount.Text);          
           
            string text = string.Format("{0}   {1}\r\n", DateTime.Now.ToShortDateString(), this.richTextBox_ShowNewCount.Text);
            File.AppendAllText("每日新加好友记录.doc", text);
            //重置
            this.TodayFriendsCount = todayFriendsCountNew;           
            this.IsHandled = true; 
            //重聚焦输入框
            this.textBox_todayCount.Focus();
            this.textBox_todayCount.SelectAll();
        }

        private void button_OpenDiary_Click(object sender, EventArgs e)
        {
            Process.Start("explorer.exe", "每日新加好友记录.doc");
        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            //定时提醒   
            if ((DateTime.Now.Hour == 17) && (DateTime.Now.Minute > 35))
            {
                if (!this.IsHandled)
                {
                    this.WindowState = FormWindowState.Normal;
                }               
            }
            //隔天重置
            if ((DateTime.Now.Hour) == 0 && (DateTime.Now.Minute == 0))
            {
                this.IsHandled = false;
                this.toolStripLabel_currentDate.Text = DateTime.Now.ToShortDateString();
            }
        }       

        private void Form1_Shown(object sender, EventArgs e)
        {
            this.toolStripLabel_currentDate.Text = DateTime.Now.ToShortDateString();
            this.IsHandled = this.IsHandled;
        }

        private void toolStripButton_reset_Click(object sender, EventArgs e)
        {
            ResetForm resetForm = new ResetForm(this);
            DialogResult dialogResult = resetForm.ShowDialog();           
            if (dialogResult == System.Windows.Forms.DialogResult.OK)
            {
                return;
            }
        }

        private void toolStripButton_Click(object sender, EventArgs e)
        {
            AudioMsgForm audioMsgForm = new AudioMsgForm();
            audioMsgForm.Show();
        }
    }
}
